@@ -5,7 +5,7 @@
 common.py
 Python 3.8+
 Date created: June 14th, 2020
-Date modified: October 27th, 2020
+Date modified: February 26th, 2022
 """
 
 import platform
@@ -13,11 +13,14 @@ import sqlite3
 import sys
 from enum import Enum
 
+VERSION = "0.5.0"
+
 
 class Platform(Enum):
     """
     An enum used to indicate the system's operating system
     """
+
     OTHER = 0
     LINUX = 1
     MAC = 2
@@ -30,11 +33,11 @@ def get_platform() -> str:
     :return: The operating system this program is running on
     """
     system = platform.system()
-    if system == 'Linux':
+    if system == "Linux":
         return str(Platform.LINUX.name)
-    if system == 'Darwin':
+    if system == "Darwin":
         return str(Platform.MAC.name)
-    if system == 'Windows':
+    if system == "Windows":
         return str(Platform.WINDOWS.name)
     raise NotImplementedError(f"Platform {system} is not supported yet!")
 
