@@ -17,8 +17,9 @@ from dataclasses import dataclass
 class MessageData:
     """
     This dataclass is the store for the data:
-    user id, text, date, service and account (destination caller id).
+    user id, text, date, service and account (caller id).
     """
+
     user_id: str
     text: str
     date: str
@@ -31,11 +32,16 @@ class MessageData:
         String representation
         :return: String representation of this object
         """
-        return f"sender (user id):\t{self.user_id}\n" \
-               f"date and time:\t\t{self.date}\n" \
-               f"service:\t\t\t{self.service}\n" \
-               f"caller id:\t\t\t{self.account}\n"\
-               f"is_from_me:\t\t\t{self.is_from_me}\n"\
-               f"----------------------------------------------------\n"\
-               f"message:\n"\
-               f"{self.text}\n"
+        return (
+            f"user id:\t\t{self.user_id}\n"
+            f"date and time:\t\t{self.date}\n"
+            f"service:\t\t{self.service}\n"
+            f"caller id:\t\t{self.account}\n"
+            f"is_from_me:\t\t{self.is_from_me}\n"
+            f"\n"
+            f"text:\n"
+            f"========\n"
+            f"{self.text}\n"
+            f"\n"
+            f"----------------------------------------------------------------\n"
+        )
